listener property
The RxBlocWidgetListener which will be called on every state change.
This listener should be used for any code which needs to execute
in response to a state change (Transition).
The state will be the nextState for the most recent Transition.
Implementation
final RxBlocWidgetListener<S> listener;