onComplete property
Callback executed once the listened state stops emitting values.
Implementation
final Function(BuildContext)? onComplete;
Callback executed once the listened state stops emitting values.
final Function(BuildContext)? onComplete;