onWaiting property

dynamic Function(BuildContext, S?)? onWaiting
final

Callback triggered once the widget has subscribed to the stream but the stream hasn't emitted any values yet. If initialValue has been specified it will be available as the second argument of the callback.

Implementation

final Function(BuildContext, S?)? onWaiting;