builder property

Widget Function(BuildContext, AsyncSnapshot<T1>, AsyncSnapshot<T2>, AsyncSnapshot<T3>, B) builder
final

The builder callback which returns a widget, executed every time there is a change in the listened state

Implementation

final Widget Function(
  BuildContext,
  AsyncSnapshot<T1>,
  AsyncSnapshot<T2>,
  AsyncSnapshot<T3>,
  B,
) builder;