RxBlocWidgetListener<S> typedef

RxBlocWidgetListener<S> = void Function(BuildContext context, S state)

Signature for the listener function which takes the BuildContext along with the bloc state and is responsible for executing in response to state changes.

Implementation

typedef RxBlocWidgetListener<S> = void Function(BuildContext context, S state);