CopyWithDecoration extension

An extension to make adding additional decoration other than the one provided by RxTextFormFieldBuilder easier

on

Methods

copyWithDecoration(InputDecoration decoration) → InputDecoration

Available on InputDecoration, provided by the CopyWithDecoration extension

Creates a copy of this input decoration with the given fields replaced by the new values from an InputDecoration passed to the function