RxFieldException<T> class

RxFieldException handles updating reactive forms with an exception without loosing the field value

See also:

  • Exception, which handles general Exceptions
Implemented types

Constructors

RxFieldException({required String error, required T fieldValue})
the default constructor, all members are required
const

Properties

error → String
The error string which the form should show
final
fieldValue → T
The value the form should be updated with in case of error used in order to NOT lose what has already been filled in
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override