RxInputDecorationData class

RxInputDecorationData is a class which defines some additional input decoration not present in the InputDecoration class intended to be used with RxTextFormFieldBuilder which internally manages the usage of the fields

See Also:

  • RxTextFormFieldBuilder - a widget for building TextFormFields with reactive streams

  • InputDecoration - The border, labels, icons, and styles used to decorate a Material Design text field.

Constructors

RxInputDecorationData({TextStyle labelStyle = const TextStyle(color: Color(0xff333333), fontWeight: FontWeight.w400, fontFamily: 'Roboto', fontStyle: FontStyle.normal, fontSize: 14), TextStyle labelStyleError = const TextStyle(color: Color(0xffff6b2a), fontWeight: FontWeight.w400, fontFamily: 'Roboto', fontStyle: FontStyle.normal, fontSize: 14), Widget iconVisibility = const Icon(Icons.visibility), Widget iconVisibilityOff = const Icon(Icons.visibility_off)})
Default constructor
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
iconVisibility → Widget
The Widget which is used as a trailing icon in the decoration generated by RxTextFormFieldBuilder if obscureText is set and and the text is currently obscured.
final
iconVisibilityOff → Widget
The Widget which is used as a trailing icon in the decoration generated by RxTextFormFieldBuilder if obscureText is set and and the text is currently not obscured.
final
labelStyle → TextStyle
The label style used when it is above the field and RxTextFormFieldBuilder doesn't detect an error
final
labelStyleError → TextStyle
The label style used when it is above the field and RxTextFormFieldBuilder detects an error
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited