builder property
The builder callback which returns a widget, executed every time there is a change in the listened state
Implementation
final Widget Function(
BuildContext,
AsyncSnapshot<T1>,
AsyncSnapshot<T2>,
B,
) builder;
The builder callback which returns a widget, executed every time there is a change in the listened state
final Widget Function(
BuildContext,
AsyncSnapshot<T1>,
AsyncSnapshot<T2>,
B,
) builder;